summaryrefslogtreecommitdiffstats
path: root/lib/kformula/fractionelement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kformula/fractionelement.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/fractionelement.h')
-rw-r--r--lib/kformula/fractionelement.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/lib/kformula/fractionelement.h b/lib/kformula/fractionelement.h
index 8a49a719..c578ee5b 100644
--- a/lib/kformula/fractionelement.h
+++ b/lib/kformula/fractionelement.h
@@ -36,7 +36,7 @@ public:
enum { numeratorPos, denominatorPos };
- FractionElement(BasicElement* parent = 0);
+ FractionElement(BasicElement* tqparent = 0);
~FractionElement();
FractionElement( const FractionElement& );
@@ -66,11 +66,11 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -78,19 +78,19 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
@@ -125,23 +125,23 @@ public:
/**
* Reinserts the denominator if it has been removed.
*/
- virtual void insert(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void insert(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
- * Removes all selected children and returns them. Places the
- * cursor to where the children have been.
+ * Removes all selected tqchildren and returns them. Places the
+ * cursor to where the tqchildren have been.
*
* We remove ourselve if we are requested to remove our numerator.
*
* It is possible to remove the denominator. But after this we
* are senseless and the caller is required to replace us.
*/
- virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
// main child
//
- // If an element has children one has to become the main one.
+ // If an element has tqchildren one has to become the main one.
virtual SequenceElement* getMainChild();
@@ -150,7 +150,7 @@ public:
/**
* Returns wether the element has no more useful
- * children (except its main child) and should therefore
+ * tqchildren (except its main child) and should therefore
* be replaced by its main child's content.
*/
virtual bool isSenseless();
@@ -182,11 +182,11 @@ public:
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
protected:
@@ -195,44 +195,44 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "FRACTION"; }
+ virtual TQString getTagName() const { return "FRACTION"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
/**
* Reads our attributes from the MathML element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromMathMLDom(const QDomElement& element);
+ virtual bool readAttributesFromMathMLDom(const TQDomElement& element);
/**
* Reads our content from the MathML node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual int readContentFromMathMLDom(QDomNode& node);
+ virtual int readContentFromMathMLDom(TQDomNode& node);
private:
- virtual QString getElementName() const { return "mfrac"; }
- virtual void writeMathMLAttributes( QDomElement& element ) const ;
- virtual void writeMathMLContent( QDomDocument& doc,
- QDomElement& element,
+ virtual TQString getElementName() const { return "mfrac"; }
+ virtual void writeMathMLAttributes( TQDomElement& element ) const ;
+ virtual void writeMathMLContent( TQDomDocument& doc,
+ TQDomElement& element,
bool oasisFormat ) const ;
double lineThickness( const ContextStyle& context, double factor );
@@ -78,19 +78,19 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/